@@ -11,7 +11,7 @@ from . import (  # noqa
     selenium,
     server,
     test_results,
-    visual_grid,
+    ultrafastgrid,
 )
 from .app_output import AppOutput  # noqa
 from .capture import EyesScreenshot  # noqa
@@ -47,11 +47,15 @@ from .scale_provider import ScaleProvider
 from .selenium import StitchMode  # noqa
 from .server import FailureReports, SessionType  # noqa
 from .test_results import TestResultContainer, TestResults, TestResultsSummary  # noqa
-from .visual_grid import (  # noqa
+from .ultrafastgrid.config import (  # noqa
     ChromeEmulationInfo,
     DeviceName,
     EmulationDevice,
+    DesktopBrowserInfo,
     RenderBrowserInfo,
+    ScreenOrientation,
+)
+from .ultrafastgrid.render import (  # noqa
     RenderInfo,
     RenderingInfo,
     RenderRequest,
@@ -59,7 +63,6 @@ from .visual_grid import (  # noqa
     RenderStatusResults,
     RGridDom,
     RunningRender,
-    ScreenOrientation,
     VGResource,
     VisualGridSelector,
 )
@@ -74,7 +77,24 @@ __all__ = (
     + capture.__all__  # noqa
     + match_window_data.__all__  # noqa
     + test_results.__all__  # noqa
-    + visual_grid.__all__  # noqa
     + server.__all__  # noqa
-    + ("logger", "StitchMode", "ScaleProvider")  # noqa
+    + (
+        "logger",
+        "StitchMode",
+        "ScaleProvider",
+        "ChromeEmulationInfo",
+        "DesktopBrowserInfo",
+        "DeviceName",
+        "EmulationDevice",
+        "ScreenOrientation",
+        "RenderInfo",
+        "RenderingInfo",
+        "RenderRequest",
+        "RenderStatus",
+        "RenderStatusResults",
+        "RGridDom",
+        "RunningRender",
+        "VGResource",
+        "VisualGridSelector",
+    )  # noqa
 )
